pub async fn record(
conn: &mut PgConnection,
new: &NewCreditRegistrationAdminAction,
) -> ModelResult<Uuid>Expand description
Call in the same transaction as the effect it audits.
pub async fn record(
conn: &mut PgConnection,
new: &NewCreditRegistrationAdminAction,
) -> ModelResult<Uuid>Call in the same transaction as the effect it audits.