pub struct NewCreditRegistrationAdminAction {
pub action: CreditRegistrationAdminAction,
pub target_kind: CreditRegistrationAdminActionTarget,
pub target_id: Option<Uuid>,
pub target_phase: Option<String>,
pub actor_user_id: Uuid,
pub actor_role: String,
pub actor_course_id: Option<Uuid>,
pub reason: Option<String>,
pub before_state: Option<CreditRegistrationState>,
pub after_state: Option<CreditRegistrationState>,
pub details: Option<Value>,
pub affected_row_count: Option<i32>,
}Fields
action: CreditRegistrationAdminActiontarget_kind: CreditRegistrationAdminActionTargettarget_id: Option<Uuid>None only for phase targets, which are keyed by target_phase.
target_phase: Option<String>actor_user_id: Uuidactor_role: Stringglobal_admin or course_teacher.
actor_course_id: Option<Uuid>The course whose edit permission authorised a teacher action.
reason: Option<String>before_state: Option<CreditRegistrationState>after_state: Option<CreditRegistrationState>details: Option<Value>Scrub before passing if this ever carries a Suotar payload.
affected_row_count: Option<i32>Trait Implementations
Sourceimpl Clone for NewCreditRegistrationAdminAction
impl Clone for NewCreditRegistrationAdminAction
Sourcefn clone(&self) -> NewCreditRegistrationAdminAction
fn clone(&self) -> NewCreditRegistrationAdminAction
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for NewCreditRegistrationAdminAction
impl PartialEq for NewCreditRegistrationAdminAction
Sourcefn eq(&self, other: &NewCreditRegistrationAdminAction) -> bool
fn eq(&self, other: &NewCreditRegistrationAdminAction) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for NewCreditRegistrationAdminAction